pub struct CatalogBuilder { /* private fields */ }Expand description
Catalog builder for EPUB navigation
The CatalogBuilder is responsible for building the navigation document (TOC)
of an EPUB publication. The navigation document provides a hierarchical table
of contents that allows readers to navigate through the publication’s content.
The navigation document is a special XHTML document that uses the EPUB Navigation Document specification.
Implementations