pub struct MetadataBuilder { /* private fields */ }Expand description
Metadata builder for EPUB publications
The MetadataBuilder is responsible for managing metadata items in an EPUB publication.
Metadata includes essential information such as title, author, language, identifier,
publisher, and other descriptive information about the publication.
Required Metadata
According to the EPUB specification, the following metadata are required:
title: The publication titlelanguage: The language of the publication (e.g., “en”, “zh-CN”)identifier: A unique identifier for the publication with id “pub-id”
Implementations
Sourceimpl MetadataBuilder
impl MetadataBuilder
Sourcepub fn add(&mut self, item: MetadataItem) -> &mut Self
pub fn add(&mut self, item: MetadataItem) -> &mut Self